.. PySHRED documentation master file, created by
   sphinx-quickstart on Tue May 20 22:32:08 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PySHRED documentation
=====================


Version: |version|

**Useful links:** `Installation <https://pyshred-dev.github.io/pyshred/stable/user_guide/installation.html>`_ | 
`Source repository <https://github.com/PyShred-Dev/PyShred>`_ |
`Issue tracker <https://github.com/pyshred-dev/pyshred/issues>`_

PySHRED is an open-source software implementing the SHallow REcurrent Decoder (SHRED) architecture for sensing applications. PySHRED achieves state-of-the-art accuracy on full-state reconstructions and forecasting of spatiotemporal dynamics from very few sensors.


.. grid:: 1 1 2 2
    :gutter: 2 3 4 4

    .. grid-item-card::
        :text-align: center

        Getting started
        ^^^

        New to PySHRED? Check out the Get Shredding Guide.

        +++

        .. button-ref:: user_guide/introduction
            :expand:
            :color: secondary
            :click-parent:

            Start shredding

    .. grid-item-card::
        :text-align: center

        User guide
        ^^^

        The user guide provides in-depth information on the
        key concepts of PySHRED with useful background information and explanation.

        +++

        .. button-ref:: user_guide/index
            :expand:
            :color: secondary
            :click-parent:

            To the user guide

    .. grid-item-card::
        :text-align: center

        API reference
        ^^^

        The reference guide contains a detailed description of the functions,
        modules, and objects included in PySHRED. The reference describes how the
        methods work and which parameters can be used. It assumes that you have an
        understanding of the key concepts.

        +++

        .. button-ref:: pyshred/modules
            :expand:
            :color: secondary
            :click-parent:

            To the reference guide

    .. grid-item-card::
        :text-align: center

        Example Gallery
        ^^^

        Explore real-world applications of PySHRED in Google Colab or Jupyter Notebook.
        +++

        .. button-ref:: examples/index
            :expand:
            :color: secondary
            :click-parent:

            To the examples

.. toctree::
   :maxdepth: 1
   :hidden:

   User Guide <user_guide/index>
   Example Gallery <examples/index>
   API Reference <pyshred/modules>
   Release Notes <release_notes/index>